@@ -6,7 +6,7 @@ import crypto from 'crypto';
 // 전체 시스템 스키마 통합 정리
 // =============================================================================
 
-const newCurrentVersion = '3.2';
+const newCurrentVersion = '3.3';
 
 // 마이그레이션 버전 관리
 const createMigrationTable = async (dbManager) => {
@@ -1119,6 +1119,59 @@ const createTables = async (dbManager) => {
 
     console.log('사용자별 시스템프롬프트 시스템 완료');
 
+    // =============================================================================
+    // 13. 웹훅 시스템 (v3.3)
+    // =============================================================================
+
+    // 웹훅 등록 테이블
+    await dbManager.query(`
+      CREATE TABLE IF NOT EXISTS webhooks (
+        id SERIAL PRIMARY KEY,
+        user_id INTEGER REFERENCES users(id) ON DELETE CASCADE,
+        url VARCHAR(500) NOT NULL,
+        events TEXT[] NOT NULL,
+        secret VARCHAR(255),
+        is_active BOOLEAN DEFAULT true,
+        retry_count INTEGER DEFAULT 3,
+        timeout_seconds INTEGER DEFAULT 30,
+        headers JSONB DEFAULT '{}',
+        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
+      );
+    `);
+
+    // 웹훅 전송 로그 테이블
+    await dbManager.query(`
+      CREATE TABLE IF NOT EXISTS webhook_logs (
+        id SERIAL PRIMARY KEY,
+        webhook_id INTEGER REFERENCES webhooks(id) ON DELETE CASCADE,
+        event_type VARCHAR(100) NOT NULL,
+        payload JSONB,
+        response_status INTEGER,
+        response_body TEXT,
+        response_headers JSONB,
+        attempts INTEGER DEFAULT 1,
+        delivered_at TIMESTAMP,
+        error_message TEXT,
+        execution_time_ms INTEGER,
+        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
+      );
+    `);
+
+    // 웹훅 인덱스 생성
+    await dbManager.query(`
+      CREATE INDEX IF NOT EXISTS idx_webhooks_user_id ON webhooks(user_id);
+      CREATE INDEX IF NOT EXISTS idx_webhooks_active ON webhooks(is_active);
+      CREATE INDEX IF NOT EXISTS idx_webhooks_events ON webhooks USING GIN(events);
+      
+      CREATE INDEX IF NOT EXISTS idx_webhook_logs_webhook_id ON webhook_logs(webhook_id);
+      CREATE INDEX IF NOT EXISTS idx_webhook_logs_event_type ON webhook_logs(event_type);
+      CREATE INDEX IF NOT EXISTS idx_webhook_logs_created_at ON webhook_logs(created_at);
+      CREATE INDEX IF NOT EXISTS idx_webhook_logs_status ON webhook_logs(response_status);
+    `);
+
+    console.log('웹훅 시스템 테이블 생성 완료');
+
     // =============================================================================
     // 13. 건강검진 배치 처리 시스템 (v2.9 - 기존 유지)
     // =============================================================================
