@@ -2,6 +2,7 @@ import React, { memo, useState } from 'react';
 import ReactMarkdown from 'react-markdown';
 import remarkGfm from 'remark-gfm';
 import remarkBreaks from 'remark-breaks';
+import rehypeRaw from 'rehype-raw';
 import Prism from 'prismjs';
 import 'prismjs/components/prism-python';
 import 'prismjs/components/prism-jsx';
@@ -248,6 +249,23 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
   
   // [REF]내용[/REF] 태그 처리 - 숫자나 URL 모두 제거
   cleanContent = cleanContent.replace(/\[REF\].*?\[\/REF\]/g, '');
+
+  // 템플릿 리터럴 치환 ({{downloadInfo[0].filename}} 등)
+  if (downloadInfo.length > 0) {
+    // downloadInfo[index].property 형태의 템플릿 치환
+    cleanContent = cleanContent.replace(/\{\{downloadInfo\[(\d+)\]\.(\w+)\}\}/g, (match, index, property) => {
+      const idx = parseInt(index);
+      if (idx < downloadInfo.length && downloadInfo[idx] && downloadInfo[idx][property]) {
+        return downloadInfo[idx][property];
+      }
+      return match; // 치환할 수 없으면 원본 유지
+    });
+  }
+
+  // HTML 버튼의 localhost URL을 동적 URL로 치환
+  const apiServerUrl = getApiServerUrl();
+  const baseUrl = apiServerUrl.replace('/api/v1', '');
+  cleanContent = cleanContent.replace(/http:\/\/localhost:5500/g, baseUrl);
   
   // 디버깅: content에 참조 정보가 있는지 확인
   // if (content.includes('REFERENCE_INFO:') || content.includes('DOWNLOAD_INFO:')) {
@@ -282,6 +300,7 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
       }} />
       <ReactMarkdown
         remarkPlugins={[remarkGfm, remarkBreaks]}
+        rehypePlugins={[rehypeRaw]}
         unwrapDisallowed={true}
         components={{
         // 강조 텍스트 (**text**)
@@ -419,6 +438,35 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
           <hr className="border-gray-300 dark:border-gray-600 my-4" />
         ),
 
+        // HTML 버튼 커스터마이징
+        button: ({ children, onClick, ...props }) => {
+          // HTML onclick 문자열을 React onClick 함수로 변환
+          const handleClick = () => {
+            if (typeof onClick === 'string') {
+              // onclick="window.open(...)" 같은 JavaScript 코드를 안전하게 파싱
+              const windowOpenMatch = onClick.match(/window\.open\(['"]([^'"]*)['"]\s*,\s*['"]([^'"]*)['"]\)/);
+              if (windowOpenMatch) {
+                const [, url, target] = windowOpenMatch;
+                window.open(url, target);
+              } else {
+                console.warn('Unsupported onclick format:', onClick);
+              }
+            } else if (typeof onClick === 'function') {
+              onClick();
+            }
+          };
+
+          return (
+            <button
+              {...props}
+              onClick={handleClick}
+              className="inline-flex items-center px-4 py-2 text-sm font-medium text-white bg-blue-600 hover:bg-blue-700 rounded-md transition-colors duration-200 mr-2 mb-2"
+            >
+              {children}
+            </button>
+          );
+        },
+
         // 표 - 개선된 스타일링
         table: ({ children }) => (
           <div className="overflow-x-auto my-4 rounded-lg border border-gray-300 dark:border-gray-600 shadow-sm">
@@ -525,8 +573,30 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
               } else {
                 // 문서는 다운로드 버튼으로 표시
                 const apiServerUrl = getApiServerUrl();
-                const downloadUrl = `${apiServerUrl}/rag/download?filename=${encodeURIComponent(item.filename)}`;
-                
+
+                // 생성된 문서와 RAG 문서를 구분하여 적절한 다운로드 URL 사용
+                let downloadUrl;
+                const isGeneratedDocument = item.source === 'generated' ||
+                                          item.filename?.includes('petition_') ||
+                                          item.filename?.includes('business_') ||
+                                          item.filename?.includes('license_') ||
+                                          item.url?.includes('/download/');
+
+                if (isGeneratedDocument) {
+                  // 생성된 문서는 /api/v1/download/{filename} 형식 사용
+                  // item.url이 이미 전체 URL이면 사용, 아니면 apiServerUrl 기반으로 구성
+                  if (item.url && (item.url.startsWith('http://') || item.url.startsWith('https://'))) {
+                    downloadUrl = item.url;
+                  } else {
+                    // apiServerUrl에서 /api/v1 부분을 제거하고 /api/v1/download 추가
+                    const baseUrl = apiServerUrl.replace('/api/v1', '');
+                    downloadUrl = `${baseUrl}/api/v1/download/${encodeURIComponent(item.filename)}`;
+                  }
+                } else {
+                  // RAG 문서는 기존 /rag/download?filename= 형식 사용
+                  downloadUrl = `${apiServerUrl}/rag/download?filename=${encodeURIComponent(item.filename)}`;
+                }
+
                 return (
                   <div key={index} className="flex items-center justify-between pl-3 p-2 bg-gray-50 dark:bg-gray-800 rounded-lg border border-gray-200 dark:border-gray-600">
                     <div className="flex items-center space-x-3">
